@@ -59,7 +59,7 @@ ListItem *list_find(GList * list, gchar * url)
 //                // printf("found %s at %p\n",url,item);
 //                return item;
 //            }
-            
+
         }
     }
 
@@ -239,7 +239,7 @@ GList *list_parse_qt(GList * list, ListItem * item)
     gchar *rmdr;                // this is data about the URL
     gchar url[1024];
     gchar *ptr;
-    unsigned int code = 0;          // some value about the URL
+    unsigned int code = 0;      // some value about the URL
 
     printf("Entering list_parse_qt localsize = %i\n", item->localsize);
 
@@ -369,7 +369,7 @@ void replace_amp(gchar * data)
     pos = g_strrstr(data, "&");
     while (pos) {
         pos[0] = '\x01';
-        pos = g_strrstr(data, "&");        
+        pos = g_strrstr(data, "&");
     }
 }
 
@@ -380,7 +380,7 @@ void unreplace_amp(gchar * data)
     pos = g_strrstr(data, "\x01");
     while (pos) {
         pos[0] = '&';
-        pos = g_strrstr(data, "\x01");        
+        pos = g_strrstr(data, "\x01");
     }
 
 }
@@ -422,6 +422,8 @@ asx_start_element(GMarkupParseContext * context,
     ListItem *newitem;
     gchar *value;
     gint i = 0;
+    gchar *ptr;
+    gchar url[1024];
 
     if (g_ascii_strcasecmp(element_name, "REF") == 0) {
         while (attribute_names[i] != NULL) {
@@ -433,7 +435,19 @@ asx_start_element(GMarkupParseContext * context,
                     newitem = g_new0(ListItem, 1);
                     value = g_strdup(attribute_values[i]);
                     unreplace_amp(value);
-                    g_strlcpy(newitem->src, value, 1024);
+                    ptr = g_strrstr(value, "/");
+                    if (ptr == NULL) {
+                        g_strlcpy(url, parser_item->src, 1024);
+                        ptr = g_strrstr(url, "/");
+                        if (ptr != NULL) {
+                            ptr[1] = (char) NULL;
+                            g_strlcpy(newitem->src, url, 1024);
+                            g_strlcat(newitem->src, value, 1024);
+                        }
+                    } else {
+                        g_strlcpy(newitem->src, value, 1024);
+                    }
+
                     g_free(value);
                     newitem->streaming = streaming(newitem->src);
                     // crappy hack, mplayer needs the protocol in lower case, some sites don't
@@ -476,7 +490,18 @@ asx_start_element(GMarkupParseContext * context,
                     newitem = g_new0(ListItem, 1);
                     value = g_strdup(attribute_values[i]);
                     unreplace_amp(value);
-                    g_strlcpy(newitem->src, value, 1024);
+                    ptr = g_strrstr(value, "/");
+                    if (ptr == NULL) {
+                        g_strlcpy(url, parser_item->src, 1024);
+                        ptr = g_strrstr(url, "/");
+                        if (ptr != NULL) {
+                            ptr[1] = (char) NULL;
+                            g_strlcpy(newitem->src, url, 1024);
+                            g_strlcat(newitem->src, value, 1024);
+                        }
+                    } else {
+                        g_strlcpy(newitem->src, value, 1024);
+                    }
                     g_free(value);
                     newitem->streaming = streaming(newitem->src);
                     // crappy hack, mplayer needs the protocol in lower case, some sites don't
